@@ -1,28 +1,22 @@
 #![allow(clippy::integer_arithmetic)]
-use {
-    log::*,
-    serde::{Deserialize, Serialize},
-    solana_sdk::{
-        clock::{Slot, UnixTimestamp},
-        deserialize_utils::default_on_eof,
-        pubkey::Pubkey,
-        signature::Signature,
-        sysvar::is_sysvar_id,
-        transaction::{Transaction, TransactionError},
-    },
-    solana_storage_proto::convert::{generated, tx_by_addr},
-    solana_transaction_status::{
-        extract_and_fmt_memos, ConfirmedBlock, ConfirmedTransaction,
-        ConfirmedTransactionStatusWithSignature, Reward, TransactionByAddrInfo,
-        TransactionConfirmationStatus, TransactionStatus, TransactionStatusMeta,
-        TransactionWithStatusMeta,
-    },
-    std::{
-        collections::{HashMap, HashSet},
-        convert::TryInto,
-    },
-    thiserror::Error,
+use log::*;
+use serde::{Deserialize, Serialize};
+use solana_sdk::{
+    clock::{Slot, UnixTimestamp},
+    pubkey::Pubkey,
+    signature::Signature,
+    sysvar::is_sysvar_id,
+    transaction::{Transaction, TransactionError},
 };
+use solana_storage_proto::convert::generated;
+use solana_storage_proto::convert::tx_by_addr;
+use solana_transaction_status::{
+    ConfirmedBlock, ConfirmedTransaction, ConfirmedTransactionStatusWithSignature, Reward,
+    TransactionByAddrInfo, TransactionConfirmationStatus, TransactionStatus, TransactionStatusMeta,
+    TransactionWithStatusMeta,
+};
+use std::{collections::HashMap, convert::TryInto};
+use thiserror::Error;
 
 #[macro_use]
 extern crate serde_derive;
@@ -70,14 +64,6 @@ fn slot_to_key(slot: Slot) -> String {
     format!("{:016x}", slot)
 }
 
-fn slot_to_blocks_key(slot: Slot) -> String {
-    slot_to_key(slot)
-}
-
-fn slot_to_tx_by_addr_key(slot: Slot) -> String {
-    slot_to_key(!slot)
-}
-
 // Reverse of `slot_to_key`
 fn key_to_slot(key: &str) -> Option<Slot> {
     match Slot::from_str_radix(key, 16) {
@@ -95,9 +81,6 @@ fn key_to_slot(key: &str) -> Option<Slot> {
 // StoredConfirmedBlock holds the same contents as ConfirmedBlock, but is slightly compressed and avoids
 // some serde JSON directives that cause issues with bincode
 //
-// Note: in order to continue to support old bincode-serialized bigtable entries, if new fields are
-// added to ConfirmedBlock, they must either be excluded or set to `default_on_eof` here
-//
 #[derive(Serialize, Deserialize)]
 struct StoredConfirmedBlock {
     previous_blockhash: String,
@@ -106,7 +89,6 @@ struct StoredConfirmedBlock {
     transactions: Vec<StoredConfirmedBlockTransaction>,
     rewards: StoredConfirmedBlockRewards,
     block_time: Option<UnixTimestamp>,
-    #[serde(deserialize_with = "default_on_eof")]
     block_height: Option<u64>,
 }
 
@@ -250,7 +232,6 @@ impl From<StoredConfirmedBlockReward> for Reward {
             lamports,
             post_balance: 0,
             reward_type: None,
-            commission: None,
         }
     }
 }
@@ -265,7 +246,7 @@ impl From<Reward> for StoredConfirmedBlockReward {
 }
 
 // A serialized `TransactionInfo` is stored in the `tx` table
-#[derive(Serialize, Deserialize, PartialEq, Debug)]
+#[derive(Serialize, Deserialize)]
 struct TransactionInfo {
     slot: Slot, // The slot that contains the block with this transaction in it
     index: u32, // Where the transaction is located in the block
@@ -273,24 +254,6 @@ struct TransactionInfo {
     memo: Option<String>, // Transaction memo
 }
 
-// Part of a serialized `TransactionInfo` which is stored in the `tx` table
-#[derive(PartialEq, Debug)]
-struct UploadedTransaction {
-    slot: Slot, // The slot that contains the block with this transaction in it
-    index: u32, // Where the transaction is located in the block
-    err: Option<TransactionError>, // None if the transaction executed successfully
-}
-
-impl From<TransactionInfo> for UploadedTransaction {
-    fn from(transaction_info: TransactionInfo) -> Self {
-        Self {
-            slot: transaction_info.slot,
-            index: transaction_info.index,
-            err: transaction_info.err,
-        }
-    }
-}
-
 impl From<TransactionInfo> for TransactionStatus {
     fn from(transaction_info: TransactionInfo) -> Self {
         let TransactionInfo { slot, err, .. } = transaction_info;
@@ -365,12 +328,7 @@ impl LedgerStorage {
     pub async fn get_confirmed_blocks(&self, start_slot: Slot, limit: usize) -> Result<Vec<Slot>> {
         let mut bigtable = self.connection.client();
         let blocks = bigtable
-            .get_row_keys(
-                "blocks",
-                Some(slot_to_blocks_key(start_slot)),
-                None,
-                limit as i64,
-            )
+            .get_row_keys("blocks", Some(slot_to_key(start_slot)), None, limit as i64)
             .await?;
         Ok(blocks.into_iter().filter_map(|s| key_to_slot(&s)).collect())
     }
@@ -381,7 +339,7 @@ impl LedgerStorage {
         let block_cell_data = bigtable
             .get_protobuf_or_bincode_cell::<StoredConfirmedBlock, generated::ConfirmedBlock>(
                 "blocks",
-                slot_to_blocks_key(slot),
+                slot_to_key(slot),
             )
             .await
             .map_err(|err| match err {
@@ -391,7 +349,7 @@ impl LedgerStorage {
         Ok(match block_cell_data {
             bigtable::CellData::Bincode(block) => block.into(),
             bigtable::CellData::Protobuf(block) => block.try_into().map_err(|_err| {
-                bigtable::Error::ObjectCorrupt(format!("blocks/{}", slot_to_blocks_key(slot)))
+                bigtable::Error::ObjectCorrupt(format!("blocks/{}", slot_to_key(slot)))
             })?,
         })
     }
@@ -428,7 +386,6 @@ impl LedgerStorage {
         let block = self.get_confirmed_block(slot).await?;
         match block.transactions.into_iter().nth(index as usize) {
             None => {
-                // report this somewhere actionable?
                 warn!("Transaction info for {} is corrupt", signature);
                 Ok(None)
             }
@@ -500,7 +457,7 @@ impl LedgerStorage {
         let starting_slot_tx_len = bigtable
             .get_protobuf_or_bincode_cell::<Vec<LegacyTransactionByAddrInfo>, tx_by_addr::TransactionByAddr>(
                 "tx-by-addr",
-                format!("{}{}", address_prefix, slot_to_tx_by_addr_key(first_slot)),
+                format!("{}{}", address_prefix, slot_to_key(!first_slot)),
             )
             .await
             .map(|cell_data| {
@@ -516,16 +473,8 @@ impl LedgerStorage {
         let tx_by_addr_data = bigtable
             .get_row_data(
                 "tx-by-addr",
-                Some(format!(
-                    "{}{}",
-                    address_prefix,
-                    slot_to_tx_by_addr_key(first_slot),
-                )),
-                Some(format!(
-                    "{}{}",
-                    address_prefix,
-                    slot_to_tx_by_addr_key(last_slot),
-                )),
+                Some(format!("{}{}", address_prefix, slot_to_key(!first_slot))),
+                Some(format!("{}{}", address_prefix, slot_to_key(!last_slot))),
                 limit as i64 + starting_slot_tx_len as i64,
             )
             .await?;
@@ -603,7 +552,6 @@ impl LedgerStorage {
             let err = meta.as_ref().and_then(|meta| meta.status.clone().err());
             let index = index as u32;
             let signature = transaction.signatures[0];
-            let memo = extract_and_fmt_memos(&transaction.message);
 
             for address in &transaction.message.account_keys {
                 if !is_sysvar_id(&address) {
@@ -614,7 +562,7 @@ impl LedgerStorage {
                             signature,
                             err: err.clone(),
                             index,
-                            memo: memo.clone(),
+                            memo: None, // TODO
                             block_time: confirmed_block.block_time,
                         });
                 }
@@ -626,7 +574,7 @@ impl LedgerStorage {
                     slot,
                     index,
                     err,
-                    memo,
+                    memo: None, // TODO
                 },
             ));
         }
@@ -635,7 +583,7 @@ impl LedgerStorage {
             .into_iter()
             .map(|(address, transaction_info_by_addr)| {
                 (
-                    format!("{}/{}", address, slot_to_tx_by_addr_key(slot)),
+                    format!("{}/{}", address, slot_to_key(!slot)),
                     tx_by_addr::TransactionByAddr {
                         tx_by_addrs: transaction_info_by_addr
                             .into_iter()
@@ -668,7 +616,7 @@ impl LedgerStorage {
         // Store the block itself last, after all other metadata about the block has been
         // successfully stored.  This avoids partial uploaded blocks from becoming visible to
         // `get_confirmed_block()` and `get_confirmed_blocks()`
-        let blocks_cells = [(slot_to_blocks_key(slot), confirmed_block.into())];
+        let blocks_cells = [(slot_to_key(slot), confirmed_block.into())];
         bytes_written += self
             .connection
             .put_protobuf_cells_with_retry::<generated::ConfirmedBlock>("blocks", &blocks_cells)
@@ -680,107 +628,6 @@ impl LedgerStorage {
 
         Ok(())
     }
-
-    // Delete a confirmed block and associated meta data.
-    pub async fn delete_confirmed_block(&self, slot: Slot, dry_run: bool) -> Result<()> {
-        let mut addresses: HashSet<&Pubkey> = HashSet::new();
-        let mut expected_tx_infos: HashMap<String, UploadedTransaction> = HashMap::new();
-        let confirmed_block = self.get_confirmed_block(slot).await?;
-        for (index, transaction_with_meta) in confirmed_block.transactions.iter().enumerate() {
-            let TransactionWithStatusMeta { meta, transaction } = transaction_with_meta;
-            let signature = transaction.signatures[0];
-            let index = index as u32;
-            let err = meta.as_ref().and_then(|meta| meta.status.clone().err());
-
-            for address in &transaction.message.account_keys {
-                if !is_sysvar_id(address) {
-                    addresses.insert(address);
-                }
-            }
-
-            expected_tx_infos.insert(
-                signature.to_string(),
-                UploadedTransaction { slot, index, err },
-            );
-        }
-
-        let address_slot_rows: Vec<_> = addresses
-            .into_iter()
-            .map(|address| format!("{}/{}", address, slot_to_tx_by_addr_key(slot)))
-            .collect();
-
-        let tx_deletion_rows = if !expected_tx_infos.is_empty() {
-            let signatures = expected_tx_infos
-                .iter()
-                .map(|(signature, _info)| signature)
-                .cloned()
-                .collect::<Vec<_>>();
-            let fetched_tx_infos: HashMap<String, std::result::Result<UploadedTransaction, _>> =
-                self.connection
-                    .get_bincode_cells_with_retry::<TransactionInfo>("tx", &signatures)
-                    .await?
-                    .into_iter()
-                    .map(|(signature, tx_info_res)| (signature, tx_info_res.map(Into::into)))
-                    .collect::<HashMap<_, _>>();
-
-            let mut deletion_rows = Vec::with_capacity(expected_tx_infos.len());
-            for (signature, expected_tx_info) in expected_tx_infos {
-                match fetched_tx_infos.get(&signature) {
-                    Some(Ok(fetched_tx_info)) if fetched_tx_info == &expected_tx_info => {
-                        deletion_rows.push(signature);
-                    }
-                    Some(Ok(fetched_tx_info)) => {
-                        warn!(
-                            "skipped tx row {} because the bigtable entry ({:?}) did not match to {:?}",
-                            signature,
-                            fetched_tx_info,
-                            &expected_tx_info,
-                        );
-                    }
-                    Some(Err(err)) => {
-                        warn!(
-                            "skipped tx row {} because the bigtable entry was corrupted: {:?}",
-                            signature, err
-                        );
-                    }
-                    None => {
-                        warn!("skipped tx row {} because it was not found", signature);
-                    }
-                }
-            }
-            deletion_rows
-        } else {
-            vec![]
-        };
-
-        if !dry_run {
-            if !address_slot_rows.is_empty() {
-                self.connection
-                    .delete_rows_with_retry("tx-by-addr", &address_slot_rows)
-                    .await?;
-            }
-
-            if !tx_deletion_rows.is_empty() {
-                self.connection
-                    .delete_rows_with_retry("tx", &tx_deletion_rows)
-                    .await?;
-            }
-
-            self.connection
-                .delete_rows_with_retry("blocks", &[slot_to_blocks_key(slot)])
-                .await?;
-        }
-
-        info!(
-            "{}deleted ledger data for slot {}: {} transaction rows, {} address slot rows",
-            if dry_run { "[dry run] " } else { "" },
-            slot,
-            tx_deletion_rows.len(),
-            address_slot_rows.len()
-        );
-
-        Ok(())
-    }
 }
 
 #[cfg(test)]
